#include "core/cpu/cpu.h"
#include "core/gpio/gpio.h"
#include "core/systick/systick.h"

// projectconfig.h: change CFG_USBHID and use CFG_PRINTF_UART
#include "core/usbhid-rom/usbhid.h"

static int oPort[] = {0, 0, 1, 2};
static int oPins[] = {8, 2, 9, 4};
static int iPort[] = {2, 2, 2, 2};
static int iPins[] = {5, 9, 10, 2};

void setupIO() {
	int	i;
	// Setup output pins
	for (i = 0; i < 4; i++) {
		gpioSetDir(oPort[i], oPins[i], gpioDirection_Output);
	}
	// Setup input pins
	for (i = 0; i < 4; i++) {
		gpioSetDir(iPort[i], iPins[i], gpioDirection_Input);
	}
	// Disable the internal pullup/down resistor on P0.7
	gpioSetPullup(&IOCON_PIO0_8, gpioPullupMode_Inactive);
	gpioSetPullup(&IOCON_PIO0_2, gpioPullupMode_Inactive);
	gpioSetPullup(&IOCON_PIO1_9, gpioPullupMode_Inactive);
	gpioSetPullup(&IOCON_PIO2_4, gpioPullupMode_Inactive);
	gpioSetPullup(&IOCON_PIO2_5, gpioPullupMode_Inactive);
	gpioSetPullup(&IOCON_PIO2_9, gpioPullupMode_Inactive);
	gpioSetPullup(&IOCON_PIO2_10, gpioPullupMode_Inactive);
	gpioSetPullup(&IOCON_PIO2_2, gpioPullupMode_Inactive);
}

void output(int val) {
	int	i;
	for (i = 0; i < 4; i++) {
		if (val & (1<<i))
			gpioSetValue(oPort[i], oPins[i], 1);
		else
			gpioSetValue(oPort[i], oPins[i], 0);
	}
}

int input() {
	int	i;
	int	val = 0;
	for (i = 0; i < 4; i++) {
		if (gpioGetValue(iPort[i], iPins[i]) != 0)
			val |= (1<<i);
	}
	return val;
}

void targetUsbHIDGetInReport (uint8_t src[], uint32_t length)
{
  src[0] = input();
}

void targetUsbHIDSetOutReport (uint8_t dst[], uint32_t length)
{
  output(dst[0]);
}

int main(void) {
	cpuInit();
	gpioInit();
	usbHIDInit();
	// setup IOs
	setupIO();

	while(1)	continue;
}
